@@ -13,7 +13,6 @@
 #include <KCrash>
 #include <KDBusService>
 #include <KLocalizedString>
-#include <KQuickAddons/QtQuickSettings>
 #include <KStartupInfo>
 #include <KWindowSystem>
 #include <QApplication>
@@ -21,9 +20,9 @@
 #include <QStandardPaths>
 #include <QTextStream>
 #include <QWindow>
+#include <QtWebView>
 
 #include <QProcessEnvironment>
-#include <QX11Info>
 
 typedef QHash<QString, DiscoverObject::CompactMode> StringCompactMode;
 Q_GLOBAL_STATIC_WITH_ARGS(StringCompactMode,
@@ -89,26 +88,23 @@ void processArgs(QCommandLineParser *parser, DiscoverObject *mainWindow)
 
 static void raiseWindow(QWindow *window)
 {
-    if (QX11Info::isPlatformX11()) {
-        KStartupInfo::setNewStartupId(window, QX11Info::nextStartupId());
-    } else if (KWindowSystem::isPlatformWayland()) {
-        KWindowSystem::setCurrentXdgActivationToken(qEnvironmentVariable("XDG_ACTIVATION_TOKEN"));
-        KWindowSystem::activateWindow(window->winId());
-    }
-    window->raise();
+    KWindowSystem::updateStartupId(window);
+    KWindowSystem::activateWindow(window);
 }
 
 int main(int argc, char **argv)
 {
     // needs to be set before we create the QGuiApplication
     QCoreApplication::setAttribute(Qt::AA_DisableSessionManager, true);
+    QtWebView::initialize();
 
     QApplication app(argc, argv);
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("plasmadiscover")));
     app.setAttribute(Qt::AA_DontCreateNativeWidgetSiblings);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+#endif
     KCrash::initialize();
-    KQuickAddons::QtQuickSettings::init();
     KLocalizedString::setApplicationDomain("plasma-discover");
     KAboutData about(QStringLiteral("discover"),
                      i18n("Discover"),
@@ -140,6 +136,7 @@ int main(int argc, char **argv)
         parser->process(app);
         about.processCommandLine(parser.data());
         DiscoverBackendsFactory::processCommandLine(parser.data(), parser->isSet(QStringLiteral("test")));
+        const bool feedback = parser->isSet(QStringLiteral("feedback"));
 
         if (parser->isSet(QStringLiteral("listbackends"))) {
             QTextStream(stdout) << i18n("Available backends:\n");
@@ -154,7 +151,7 @@ int main(int argc, char **argv)
             QStandardPaths::setTestModeEnabled(true);
         }
 
-        KDBusService *service = new KDBusService(KDBusService::Unique, &app);
+        KDBusService *service = !feedback ? new KDBusService(KDBusService::Unique, &app) : nullptr;
 
         {
             auto options = parser->optionNames();
@@ -163,26 +160,37 @@ int main(int argc, char **argv)
             QVariantMap initialProperties;
             if (!options.isEmpty() || !parser->positionalArguments().isEmpty())
                 initialProperties = {{QStringLiteral("currentTopLevel"), QStringLiteral("qrc:/qml/LoadingPage.qml")}};
+            if (feedback) {
+                initialProperties.insert("visible", false);
+            }
             mainWindow = new DiscoverObject(s_decodeCompactMode->value(parser->value(QStringLiteral("compact")), DiscoverObject::Full), initialProperties);
         }
+        if (feedback) {
+            QTextStream(stdout) << mainWindow->describeSources() << '\n';
+            delete mainWindow;
+            return 0;
+        } else {
+            auto onActivateRequested = [mainWindow](const QStringList &arguments, const QString & /*workingDirectory*/) {
+                mainWindow->restore();
+                auto window = qobject_cast<QWindow *>(mainWindow->rootObject());
+                if (!window) {
+                    // Should never happen anyway
+                    QCoreApplication::instance()->quit();
+                    return;
+                }
+
+                raiseWindow(window);
+
+                if (arguments.isEmpty())
+                    return;
+                QScopedPointer<QCommandLineParser> parser(createParser());
+                parser->parse(arguments);
+                processArgs(parser.data(), mainWindow);
+            };
+            QObject::connect(service, &KDBusService::activateRequested, mainWindow, onActivateRequested);
+        }
+
         QObject::connect(&app, &QCoreApplication::aboutToQuit, mainWindow, &DiscoverObject::deleteLater);
-        auto onActivateRequested = [mainWindow](const QStringList &arguments, const QString & /*workingDirectory*/) {
-            auto window = qobject_cast<QWindow *>(mainWindow->rootObject());
-            if (!window) {
-                // Should never happen anyway
-                QCoreApplication::instance()->quit();
-                return;
-            }
-
-            raiseWindow(window);
-
-            if (arguments.isEmpty())
-                return;
-            QScopedPointer<QCommandLineParser> parser(createParser());
-            parser->parse(arguments);
-            processArgs(parser.data(), mainWindow);
-        };
-        QObject::connect(service, &KDBusService::activateRequested, mainWindow, onActivateRequested);
 
         processArgs(parser.data(), mainWindow);
 
@@ -195,12 +203,6 @@ int main(int argc, char **argv)
             return 0;
         }
 
-        if (parser->isSet(QStringLiteral("feedback"))) {
-            QTextStream(stdout) << mainWindow->describeSources() << '\n';
-            delete mainWindow;
-            return 0;
-        }
-
         if (parser->isSet(QStringLiteral("test"))) {
             const QUrl testFile = QUrl::fromUserInput(parser->value(QStringLiteral("test")), {}, QUrl::AssumeLocalFile);
             Q_ASSERT(!testFile.isEmpty() && testFile.isLocalFile());
