@@ -92,15 +92,17 @@ void ReviewsModel::setResource(AbstractResource *app)
 
         if (m_backend) {
             disconnect(m_backend, &AbstractReviewsBackend::reviewsReady, this, &ReviewsModel::addReviews);
+            disconnect(m_backend, &AbstractReviewsBackend::fetchingChanged, this, &ReviewsModel::fetchingChanged);
             disconnect(m_app, &AbstractResource::versionsChanged, this, &ReviewsModel::restartFetching);
         }
         m_app = app;
         m_backend = app ? app->backend()->reviewsBackend() : nullptr;
         if (m_backend) {
             connect(m_backend, &AbstractReviewsBackend::reviewsReady, this, &ReviewsModel::addReviews);
+            connect(m_backend, &AbstractReviewsBackend::fetchingChanged, this, &ReviewsModel::fetchingChanged);
             connect(m_app, &AbstractResource::versionsChanged, this, &ReviewsModel::restartFetching);
 
-            QMetaObject::invokeMethod(this, "restartFetching", Qt::QueuedConnection);
+            QMetaObject::invokeMethod(this, &ReviewsModel::restartFetching, Qt::QueuedConnection);
         }
         endResetModel();
         Q_EMIT rowsChanged();
@@ -135,7 +137,7 @@ void ReviewsModel::addReviews(AbstractResource *app, const QVector<ReviewPtr> &r
         return;
 
     m_canFetchMore = canFetchMore;
-    // qCDebug(LIBDISCOVER_LOG) << "reviews arrived..." << m_lastPage << reviews.size();
+    qCDebug(LIBDISCOVER_LOG) << "reviews arrived..." << m_lastPage << reviews.size();
 
     if (!reviews.isEmpty()) {
         beginInsertRows(QModelIndex(), rowCount(), rowCount() + reviews.size() - 1);
@@ -172,4 +174,9 @@ void ReviewsModel::flagReview(int row, const QString &reason, const QString &tex
     m_backend->flagReview(r, reason, text);
 }
 
+bool ReviewsModel::isFetching() const
+{
+    return m_backend && m_backend->isFetching();
+}
+
 #include "moc_ReviewsModel.cpp"
