@@ -9,12 +9,13 @@
 #include "utils.h"
 #include <AppStreamQt/release.h>
 #include <AppStreamQt/screenshot.h>
+#include <AppStreamQt/spdx.h>
+#include <AppStreamQt/version.h>
 #include <KLocalizedString>
 #include <QDebug>
 #include <QJsonArray>
 #include <QJsonObject>
 #include <QUrlQuery>
-#include <AppStreamQt/spdx.h>
 
 using namespace AppStreamUtils;
 
@@ -137,3 +138,91 @@ QString AppStreamUtils::versionString(const QString &version, const AppStream::C
         }
     }
 }
+
+QString AppStreamUtils::contentRatingDescription(const AppStream::Component &appdata)
+{
+#if ASQ_CHECK_VERSION(0, 15, 6)
+    const auto ratings = appdata.contentRatings();
+    QString ret;
+    for (const auto &r : ratings) {
+        const auto ratingIds = r.ratingIds();
+        for (const auto &id : ratingIds) {
+            if (r.value(id) != AppStream::ContentRating::RatingValueNone) {
+                ret += QLatin1String("* ") + r.description(id) + QLatin1Char('\n');
+            }
+        }
+    }
+
+    return ret;
+#else
+    Q_UNUSED(appdata);
+    return {};
+#endif
+}
+
+QString AppStreamUtils::contentRatingText(const AppStream::Component &appdata)
+{
+#if ASQ_CHECK_VERSION(0, 15, 6)
+    const auto ratings = appdata.contentRatings();
+    AppStream::ContentRating::RatingValue intensity = AppStream::ContentRating::RatingValueUnknown;
+    for (const auto &r : ratings) {
+        const auto ratingIds = r.ratingIds();
+        for (const auto &id : ratingIds) {
+            intensity = std::max(r.value(id), intensity);
+        }
+    }
+
+    static QStringList texts = {
+        {},
+        i18n("All Audiences"),
+        i18nc("As specified in OARS, intensity of contents", "Mild Content"),
+        i18nc("As specified in OARS, intensity of contents", "Moderate Content"),
+        i18nc("As specified in OARS, intensity of contents", "Intense Content"),
+    };
+    return texts[intensity];
+#else
+    Q_UNUSED(appdata);
+    return {};
+#endif
+}
+
+AbstractResource::ContentIntensity AppStreamUtils::contentRatingIntensity(const AppStream::Component &appdata)
+{
+#if ASQ_CHECK_VERSION(0, 15, 6)
+    const auto ratings = appdata.contentRatings();
+    AppStream::ContentRating::RatingValue intensity = AppStream::ContentRating::RatingValueUnknown;
+    for (const auto &r : ratings) {
+        const auto ratingIds = r.ratingIds();
+        for (const auto &id : ratingIds) {
+            intensity = std::max(r.value(id), intensity);
+        }
+    }
+
+    static QVector<AbstractResource::ContentIntensity> intensities = {
+        AbstractResource::Mild,
+        AbstractResource::Mild,
+        AbstractResource::Mild,
+        AbstractResource::Intense,
+        AbstractResource::Intense,
+    };
+    return intensities[intensity];
+#else
+    Q_UNUSED(appdata);
+    return {};
+#endif
+}
+
+uint AppStreamUtils::contentRatingMinimumAge(const AppStream::Component &appdata)
+{
+#if ASQ_CHECK_VERSION(0, 15, 6)
+    const auto ratings = appdata.contentRatings();
+    uint minimumAge = 0;
+    for (const auto &r : ratings) {
+        minimumAge = std::max(r.minimumAge(), minimumAge);
+    }
+    return minimumAge;
+#else
+    Q_UNUSED(appdata);
+    return 0;
+#endif
+}
