@@ -39,6 +39,7 @@ DummyBackend::DummyBackend(QObject *parent)
     if (!m_fetching)
         m_reviews->initialize();
 
+    m_updater->setErrorMessage(QStringLiteral("I am super broken"));
     SourcesModel::global()->addSourcesBackend(new DummySourcesBackend(this));
 }
 
@@ -93,7 +94,7 @@ ResultsStream *DummyBackend::search(const AbstractResourcesBackend::Filters &fil
     if (!filter.resourceUrl.isEmpty())
         return findResourceByPackageName(filter.resourceUrl);
     else
-        foreach (AbstractResource *r, m_resources) {
+        for (AbstractResource *r : qAsConst(m_resources)) {
             if (r->type() == AbstractResource::Technical && filter.state != AbstractResource::Upgradeable) {
                 continue;
             }
@@ -158,6 +159,8 @@ void DummyBackend::checkForUpdates()
     populate(QStringLiteral("Moar"));
     QTimer::singleShot(500, this, &DummyBackend::toggleFetching);
     qDebug() << "DummyBackend::checkForUpdates";
+
+    Q_EMIT passiveMessage("Dummy: Checking for updates");
 }
 
 QString DummyBackend::displayName() const
