@@ -8,7 +8,6 @@
 #include "FlatpakResource.h"
 #include "FlatpakBackend.h"
 #include "FlatpakFetchDataJob.h"
-#include "FlatpakPermission.h"
 #include "FlatpakSourcesBackend.h"
 #include "config-paths.h"
 
@@ -16,6 +15,7 @@
 
 #include <AppStreamQt/icon.h>
 #include <AppStreamQt/screenshot.h>
+#include <AppStreamQt/utils.h>
 #include <appstream/AppStreamUtils.h>
 
 #include <KConfigGroup>
@@ -27,6 +27,7 @@
 #include <QDebug>
 #include <QDesktopServices>
 #include <QDir>
+#include <QDirIterator>
 #include <QFileInfo>
 #include <QIcon>
 #include <QNetworkAccessManager>
@@ -44,7 +45,9 @@ static QString iconCachePath(const AppStream::Icon &icon)
     return QStringLiteral("%1/icons/%2").arg(QStandardPaths::writableLocation(QStandardPaths::CacheLocation), icon.url().fileName());
 }
 
-const QStringList FlatpakResource::s_objects({QStringLiteral("qrc:/qml/FlatpakAttention.qml"), QStringLiteral("qrc:/qml/FlatpakRemoveData.qml")});
+const QStringList FlatpakResource::s_objects({QStringLiteral("qrc:/qml/FlatpakAttention.qml"),
+                                              QStringLiteral("qrc:/qml/FlatpakRemoveData.qml"),
+                                              QStringLiteral("qrc:/qml/FlatpakOldBeta.qml")});
 const QStringList FlatpakResource::s_bottomObjects({QStringLiteral("qrc:/qml/PermissionsList.qml")});
 
 FlatpakResource::FlatpakResource(const AppStream::Component &component, FlatpakInstallation *installation, FlatpakBackend *parent)
@@ -103,16 +106,16 @@ QList<PackageState> FlatpakResource::addonsInformation()
 
 QString FlatpakResource::availableVersion() const
 {
-    QString theBranch = branch();
-    if (theBranch.isEmpty()) {
-        theBranch = i18n("Unknown");
+    if (m_availableVersion.isEmpty()) {
+        const auto releases = m_appdata.releases();
+        if (!releases.isEmpty()) {
+            m_availableVersion = releases.constFirst().version();
+            return m_availableVersion;
+        }
+    } else {
+        return m_availableVersion;
     }
-
-    if (!m_availableVersion.isEmpty()) {
-        return i18nc("version (branch)", "%1 (%2)", m_availableVersion, theBranch);
-    }
-
-    return theBranch;
+    return branch();
 }
 
 QString FlatpakResource::appstreamId() const
@@ -203,9 +206,21 @@ QVariant FlatpakResource::icon() const
         for (const AppStream::Icon &icon : icons) {
             switch (icon.kind()) {
             case AppStream::Icon::KindLocal:
-            case AppStream::Icon::KindCached:
-                ret.addFile(icon.url().toLocalFile(), icon.size());
-                break;
+            case AppStream::Icon::KindCached: {
+                const QString path = icon.url().toLocalFile();
+                if (QDir::isRelativePath(path)) {
+                    const QString appstreamLocation = installationPath() + "/appstream/" + origin() + '/' + flatpak_get_default_arch() + "/active/icons/";
+                    QDirIterator dit(appstreamLocation, QDirIterator::Subdirectories);
+                    while (dit.hasNext()) {
+                        const auto currentPath = dit.next();
+                        if (dit.fileName() == path) {
+                            ret.addFile(currentPath, icon.size());
+                        }
+                    }
+                } else {
+                    ret.addFile(path, icon.size());
+                }
+            } break;
             case AppStream::Icon::KindStock: {
                 const auto ret = QIcon::fromTheme(icon.name());
                 if (!ret.isNull())
@@ -233,19 +248,15 @@ QVariant FlatpakResource::icon() const
 
 QString FlatpakResource::installedVersion() const
 {
-    QString version = branch();
-    if (version.isEmpty()) {
-        version = i18n("Unknown");
-    }
-
     g_autoptr(FlatpakInstalledRef) ref = qobject_cast<FlatpakBackend *>(backend())->getInstalledRefForApp(this);
     if (ref) {
         const char *appdataVersion = flatpak_installed_ref_get_appdata_version(ref);
+
         if (appdataVersion) {
-            return i18nc("version (branch)", "%1 (%2)", appdataVersion, version);
+            return appdataVersion;
         }
     }
-    return version;
+    return branch();
 }
 
 quint64 FlatpakResource::installedSize() const
@@ -285,6 +296,11 @@ QUrl FlatpakResource::donationURL()
     return m_appdata.url(AppStream::Component::UrlKindDonation);
 }
 
+QUrl FlatpakResource::contributeURL()
+{
+    return m_appdata.url(AppStream::Component::UrlKindContribute);
+}
+
 FlatpakResource::FlatpakFileType FlatpakResource::flatpakFileType() const
 {
     return m_flatpakFileType;
@@ -308,9 +324,7 @@ QJsonArray FlatpakResource::licenses()
 
 QString FlatpakResource::longDescription()
 {
-    QString description = m_appdata.description();
-
-    return description;
+    return m_appdata.description();
 }
 
 QString FlatpakResource::attentionText() const
@@ -357,6 +371,11 @@ QString FlatpakResource::origin() const
     return m_origin;
 }
 
+QString FlatpakResource::displayOrigin() const
+{
+    return !m_displayOrigin.isEmpty() ? m_displayOrigin : m_origin;
+}
+
 QString FlatpakResource::packageName() const
 {
     return flatpakName() + QLatin1Char('/') + arch() + QLatin1Char('/') + branch();
@@ -445,7 +464,16 @@ FlatpakResource::Id FlatpakResource::uniqueId() const
 
 void FlatpakResource::invokeApplication() const
 {
-    const QString desktopFile = installPath() + QLatin1String("/export/share/applications/") + appstreamId();
+    QString desktopFileName;
+    auto launchables = m_appdata.launchable(AppStream::Launchable::KindDesktopId).entries();
+    if (!launchables.isEmpty()) {
+        desktopFileName = launchables.constFirst();
+    } else {
+        qWarning() << "Failed to find launchable for " << m_appdata.name() << ", using AppStream identifier instead";
+        desktopFileName = appstreamId();
+    }
+
+    const QString desktopFile = installPath() + QLatin1String("/export/share/applications/") + desktopFileName;
     const QString runservice = QStringLiteral(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5 "/discover/runservice");
     if (QFile::exists(desktopFile) && QFile::exists(runservice)) {
         QProcess::startDetached(runservice, {desktopFile});
@@ -535,6 +563,11 @@ void FlatpakResource::setOrigin(const QString &origin)
     m_origin = origin;
 }
 
+void FlatpakResource::setDisplayOrigin(const QString &displayOrigin)
+{
+    m_displayOrigin = displayOrigin;
+}
+
 void FlatpakResource::setPropertyState(FlatpakResource::PropertyKind kind, FlatpakResource::PropertyState newState)
 {
     auto &state = m_propertyStates[kind];
@@ -851,17 +884,54 @@ void FlatpakResource::loadPermissions()
 
 QString FlatpakResource::dataLocation() const
 {
-    auto id = m_appdata.bundle(AppStream::Bundle::KindFlatpak).id();
-    return QDir::homePath() + QLatin1String("/.var/") + id.section('/', 0, 1);
+    auto id = m_appdata.bundle(AppStream::Bundle::KindFlatpak).id().section('/', 0, 1);
+    if (id.isEmpty()) {
+        return {};
+    }
+    return QDir::homePath() + QLatin1String("/.var/") + id;
 }
 
 bool FlatpakResource::hasDataButUninstalled() const
 {
-    return m_state == None && QDir(dataLocation()).exists();
+    return m_state == None && !dataLocation().isEmpty() && QDir(dataLocation()).exists();
 }
 
 void FlatpakResource::clearUserData()
 {
-    QDir(dataLocation()).removeRecursively();
+    const auto location = dataLocation();
+    if (location.isEmpty()) {
+        qWarning() << "Failed find location for" << name();
+        return;
+    }
+
+    if (!QDir(location).removeRecursively()) {
+        qWarning() << "Failed to remove location" << location;
+    }
     Q_EMIT hasDataButUninstalledChanged();
 }
+
+int FlatpakResource::versionCompare(FlatpakResource *resource) const
+{
+    const QString other = resource->availableVersion();
+    return AppStream::Utils::vercmpSimple(availableVersion(), other);
+}
+
+QString FlatpakResource::contentRatingDescription() const
+{
+    return AppStreamUtils::contentRatingDescription(m_appdata);
+}
+
+QString FlatpakResource::contentRatingText() const
+{
+    return AppStreamUtils::contentRatingText(m_appdata);
+}
+
+AbstractResource::ContentIntensity FlatpakResource::contentRatingIntensity() const
+{
+    return AppStreamUtils::contentRatingIntensity(m_appdata);
+}
+
+uint FlatpakResource::contentRatingMinimumAge() const
+{
+    return AppStreamUtils::contentRatingMinimumAge(m_appdata);
+}
