@@ -9,6 +9,7 @@
 
 #include <ReviewsBackend/AbstractReviewsBackend.h>
 #include <attica/provider.h>
+#include <knewstuffcore_version.h>
 
 class KNSBackend;
 class QUrl;
@@ -27,26 +28,28 @@ public:
     bool isFetching() const override;
     void flagReview(Review *r, const QString &reason, const QString &text) override;
     void deleteReview(Review *r) override;
-    void submitReview(AbstractResource *app, const QString &summary, const QString &review_text, const QString &rating) override;
     void submitUsefulness(Review *r, bool useful) override;
     void logout() override;
     void registerAndLogin() override;
     void login() override;
     Rating *ratingForApplication(AbstractResource *app) const override;
     bool hasCredentials() const override;
-    QString userName() const override;
 
-    void setProviderUrl(const QUrl &url);
     bool isResourceSupported(AbstractResource *res) const override;
 
+protected:
+    void sendReview(AbstractResource *app, const QString &summary, const QString &review_text, const QString &rating, const QString &userName) override;
+    QString userName() const override;
+
 private Q_SLOTS:
     void commentsReceived(Attica::BaseJob *job);
     void credentialsReceived(const QString &user, const QString &password);
 
 private:
     Attica::Provider provider() const;
+    void acquireFetching(bool f);
+
     KNSBackend *const m_backend;
-    QUrl m_providerUrl;
     int m_fetching = 0;
 };
 
