@@ -148,6 +148,11 @@ QUrl AppPackageKitResource::donationURL()
     return m_appdata.url(AppStream::Component::UrlKindDonation);
 }
 
+QUrl AppPackageKitResource::contributeURL()
+{
+    return m_appdata.url(AppStream::Component::UrlKindContribute);
+}
+
 AbstractResource::Type AppPackageKitResource::type() const
 {
     static QString desktop = QString::fromUtf8(qgetenv("XDG_CURRENT_DESKTOP"));
@@ -243,3 +248,23 @@ bool AppPackageKitResource::isCritical() const
 {
     return m_appdata.isCompulsoryForDesktop(qEnvironmentVariable("XDG_CURRENT_DESKTOP"));
 }
+
+QString AppPackageKitResource::contentRatingDescription() const
+{
+    return AppStreamUtils::contentRatingDescription(m_appdata);
+}
+
+QString AppPackageKitResource::contentRatingText() const
+{
+    return AppStreamUtils::contentRatingText(m_appdata);
+}
+
+AbstractResource::ContentIntensity AppPackageKitResource::contentRatingIntensity() const
+{
+    return AppStreamUtils::contentRatingIntensity(m_appdata);
+}
+
+uint AppPackageKitResource::contentRatingMinimumAge() const
+{
+    return AppStreamUtils::contentRatingMinimumAge(m_appdata);
+}
