@@ -28,6 +28,7 @@ public:
     QUrl helpURL() override;
     QUrl bugURL() override;
     QUrl donationURL() override;
+    QUrl contributeURL() override;
     QString comment() override;
     QJsonArray licenses() override;
     QStringList allPackageNames() const override;
@@ -44,6 +45,11 @@ public:
     QSet<QString> alternativeAppstreamIds() const override;
     bool isCritical() const override;
 
+    QString contentRatingText() const override;
+    QString contentRatingDescription() const override;
+    ContentIntensity contentRatingIntensity() const override;
+    uint contentRatingMinimumAge() const override;
+
 private:
     const AppStream::Component m_appdata;
     mutable QString m_name;
