@@ -296,10 +296,12 @@ void PKTransaction::eulaRequired(const QString &eulaID, const QString &packageID
 
 void PKTransaction::errorFound(PackageKit::Transaction::Error err, const QString &error)
 {
-    if (err == PackageKit::Transaction::ErrorNoLicenseAgreement || err == PackageKit::Transaction::ErrorTransactionCancelled)
+    if (err == PackageKit::Transaction::ErrorNoLicenseAgreement || err == PackageKit::Transaction::ErrorTransactionCancelled
+        || err == PackageKit::Transaction::ErrorNotAuthorized) {
         return;
-    qWarning() << "PackageKit error:" << err << PackageKitMessages::errorMessage(err) << error;
-    Q_EMIT passiveMessage(PackageKitMessages::errorMessage(err));
+    }
+    qWarning() << "PackageKit error:" << err << PackageKitMessages::errorMessage(err, error) << error;
+    Q_EMIT passiveMessage(PackageKitMessages::errorMessage(err, error));
 }
 
 void PKTransaction::mediaChange(PackageKit::Transaction::MediaType media, const QString &type, const QString &text)
