@@ -22,7 +22,6 @@
 #include <resources/StandardBackendUpdater.h>
 
 #include <QDebug>
-#include <QFile>
 #include <QFileSystemWatcher>
 #include <QFutureWatcher>
 #include <QMimeDatabase>
@@ -234,7 +233,7 @@ void PackageKitBackend::reloadPackageList()
         }
         for (const AppStream::Component &dc : distroComponents) {
             const auto releases = dc.releases();
-            for (auto r : releases) {
+            for (const auto &r : releases) {
                 int cmp = AppStream::Utils::vercmpSimple(r.version(), AppStreamIntegration::global()->osRelease()->versionId());
                 if (cmp == 0) {
                     // Ignore (likely) empty date_eol entries that are parsed as the UNIX Epoch
@@ -777,11 +776,9 @@ bool PackageKitBackend::isPackageNameUpgradeable(const PackageKitResource *res)
 // It's an optimisation as there's a bunch of allocations that happen from packageName
 // Having packageName return a QStringRef or a QStringView would fix this issue.
 // TODO Qt 6: Have packageName and similars return a QStringView
-static QStringRef TransactionpackageName(const QString &packageID)
+static QStringView TransactionpackageName(const QString &packageID)
 {
-    QStringRef ret;
-    ret = packageID.leftRef(packageID.indexOf(QLatin1Char(';')));
-    return ret;
+    return QStringView(packageID).left(packageID.indexOf(QLatin1Char(';')));
 }
 
 QSet<QString> PackageKitBackend::upgradeablePackageId(const PackageKitResource *res) const
