@@ -43,6 +43,7 @@ class DISCOVERCOMMON_EXPORT AbstractBackendUpdater : public QObject
     Q_PROPERTY(bool isProgressing READ isProgressing NOTIFY progressingChanged)
     Q_PROPERTY(bool needsReboot READ needsReboot NOTIFY needsRebootChanged)
     Q_PROPERTY(quint64 downloadSpeed READ downloadSpeed NOTIFY downloadSpeedChanged)
+    Q_PROPERTY(QString errorMessage READ errorMessage NOTIFY errorMessageChanged)
 public:
     enum State {
         None,
@@ -50,7 +51,7 @@ public:
         Installing,
         Done,
     };
-    Q_ENUM(State);
+    Q_ENUM(State)
 
     /**
      * Constructs an AbstractBackendUpdater
@@ -124,7 +125,9 @@ public:
     virtual quint64 downloadSpeed() const = 0;
 
     void enableNeedsReboot();
+    void enableReadyToReboot();
 
+    bool isReadyToReboot() const;
     bool needsReboot() const;
 
     virtual void setOfflineUpdates(bool useOfflineUpdates);
@@ -157,6 +160,12 @@ public Q_SLOTS:
     {
     }
 
+    void setErrorMessage(const QString &errorMessage);
+    QString errorMessage() const
+    {
+        return m_errorMessage;
+    }
+
 Q_SIGNALS:
     /**
      * The AbstractBackendUpdater should Q_EMIT this signal when the progress changed.
@@ -205,13 +214,24 @@ Q_SIGNALS:
      */
     void proceedRequest(const QString &title, const QString &description);
 
+    /**
+     * A fatal error was found on distro packaging. Provide a @p message to show
+     * in a modal dialog that should lead the user towards reporting the problem..
+     */
+    void distroErrorMessage(const QString &message);
+
     /**
      * emitted when the updater decides it needs to reboot
      */
     void needsRebootChanged();
 
+    /** emitted when we find a new errorMessage to display */
+    void errorMessageChanged();
+
 private:
     bool m_needsReboot = false;
+    bool m_readyToReboot = false;
+    QString m_errorMessage;
 };
 
 #endif // ABSTRACTBACKENDUPDATER_H
