@@ -70,7 +70,7 @@ DiscoverNotifier::DiscoverNotifier(QObject *parent)
     updateStatusNotifier();
 
     // Only fetch updates after the system is comfortably booted
-    QTimer::singleShot(20s, this, &DiscoverNotifier::recheckSystemUpdateNeeded);
+    QTimer::singleShot(0s, this, &DiscoverNotifier::recheckSystemUpdateNeeded);
 }
 
 DiscoverNotifier::~DiscoverNotifier() = default;
@@ -100,13 +100,36 @@ void DiscoverNotifier::showDiscoverUpdates(const QString &xdgActivationToken)
     }
 }
 
+bool DiscoverNotifier::notifyAboutUpdates() const
+{
+    if (state() != NormalUpdates && state() != SecurityUpdates) {
+        // it's not very helpful to notify that everything is in order
+        return false;
+    }
+
+    if (m_settings->requiredNotificationInterval() < 0) {
+        return false;
+    }
+
+    // To configure to a random value, execute:
+    // kwriteconfig5 --file PlasmaDiscoverUpdates --group Global --key RequiredNotificationInterval 3600
+    const QDateTime timeSinceLastRefresh = m_settings->lastNotificationTime().addSecs(m_settings->requiredNotificationInterval());
+    if (!timeSinceLastRefresh.isValid() || timeSinceLastRefresh > QDateTime::currentDateTimeUtc()) {
+        return false;
+    }
+
+    m_settings->setLastNotificationTime(QDateTime::currentDateTimeUtc());
+    m_settings->save();
+    return true;
+}
+
 void DiscoverNotifier::showUpdatesNotification()
 {
     if (m_updatesAvailableNotification) {
         m_updatesAvailableNotification->close();
     }
-    if (state() != NormalUpdates && state() != SecurityUpdates) {
-        // it's not very helpful to notify that everything is in order
+
+    if (!notifyAboutUpdates()) {
         return;
     }
 
@@ -165,6 +188,11 @@ static bool isConnectionAdequate()
 void DiscoverNotifier::refreshUnattended()
 {
     m_settings->read();
+
+    if (!notifyAboutUpdates()) {
+        return;
+    }
+
     const auto enabled = m_settings->useUnattendedUpdates()
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         && m_manager->isOnline() && isConnectionAdequate(m_manager->defaultConfiguration());
